@@ -60,18 +60,24 @@ def format_time_ns_min_unit(time_ns, min_unit, machine_friendly):
     if machine_friendly:
         return '%d' % time_ns
 
+    if time_ns < 0:
+        sign = '-'
+        time_ns = -1 * time_ns
+    else:
+        sign = ''
+
     if time_ns >= ulong_max:
-        return 'max'
+        return '%smax' % sign
 
     for unit_nsecs in sorted(nsecs_to_unit.keys(), reverse=True):
         if time_ns < unit_nsecs:
             continue
         if unit_nsecs == min_unit:
             if time_ns % unit_nsecs:
-                return '%.3f %s' % (time_ns / unit_nsecs,
+                return '%s%.3f %s' % (sign, time_ns / unit_nsecs,
                         nsecs_to_unit[unit_nsecs])
             else:
-                return '%d %s' % (time_ns / unit_nsecs,
+                return '%s%d %s' % (sign, time_ns / unit_nsecs,
                         nsecs_to_unit[unit_nsecs])
 
         unit_nr = int(time_ns / unit_nsecs)
@@ -80,10 +86,11 @@ def format_time_ns_min_unit(time_ns, min_unit, machine_friendly):
 
         less_unit_ns = time_ns - unit_nr * unit_nsecs
         if less_unit_ns == 0:
-            return unit_str
+            return '%s%s' % (sign, unit_str)
         else:
-            return '%s %s' % (unit_str, format_time_ns_min_unit(less_unit_ns,
-                min_unit, False))
+            return '%s%s %s' % (
+                    sign, unit_str, format_time_ns_min_unit(
+                        less_unit_ns, min_unit, False))
     return '0 ns'
 
 def format_time_ns_exact(time_ns, machine_friendly):
@@ -100,8 +107,13 @@ def format_time_ns(time_ns, machine_friendly):
         return '%d' % time_ns
 
     time_ns = float(time_ns)
+    if time_ns < 0:
+        sign = '-'
+        time_ns = time_ns * -1
+    else:
+        sign = ''
     if time_ns >= ulong_max:
-        return 'max'
+        return '%smax' % sign
 
     if time_ns >= hour_ns:
         hour = int(time_ns / hour_ns)
@@ -109,29 +121,30 @@ def format_time_ns(time_ns, machine_friendly):
 
         less_hour_ns = time_ns - (hour * hour_ns)
         if less_hour_ns == 0:
-            return hour_str
-        return '%s %s' % (hour_str, format_time_ns(less_hour_ns, False))
+            return '%s%s' % (sign, hour_str)
+        return '%s%s %s' % (
+                sign, hour_str, format_time_ns(less_hour_ns, False))
     if time_ns >= minute_ns:
         if time_ns % minute_ns == 0:
-            return '%d m' % (time_ns / minute_ns)
+            return '%s%d m' % (sign, time_ns / minute_ns)
         if time_ns % sec_ns == 0:
-            return '%d m %d s' % (time_ns / minute_ns,
+            return '%s%d m %d s' % (sign, time_ns / minute_ns,
                     (time_ns % minute_ns) / sec_ns)
-        return '%d m %.3f s' % (time_ns / minute_ns,
+        return '%s%d m %.3f s' % (sign, time_ns / minute_ns,
                 (time_ns % minute_ns) / sec_ns)
     if time_ns >= sec_ns:
         if time_ns % sec_ns == 0:
-            return '%d s' % (time_ns / sec_ns)
-        return '%.3f s' % (time_ns / sec_ns)
+            return '%s%d s' % (sign, time_ns / sec_ns)
+        return '%s%.3f s' % (sign, time_ns / sec_ns)
     if time_ns >= ms_ns:
         if time_ns % ms_ns == 0:
-            return '%d ms' % (time_ns / ms_ns)
-        return '%.3f ms' % (time_ns / ms_ns)
+            return '%s%d ms' % (sign, time_ns / ms_ns)
+        return '%s%.3f ms' % (sign, time_ns / ms_ns)
     if time_ns >= us_ns:
         if time_ns % us_ns == 0:
-            return '%d us' % (time_ns / us_ns)
-        return '%.3f us' % (time_ns / us_ns)
-    return '%d ns' % time_ns
+            return '%s%d us' % (sign, time_ns / us_ns)
+        return '%s%.3f us' % (sign, time_ns / us_ns)
+    return '%s%d ns' % (sign, time_ns)
 
 def format_time_us(time_us, machine_friendly):
     if machine_friendly:
