@@ -725,7 +725,7 @@ class DamosFilter:
     allow = None
     memcg_path = None
     address_range = None    # DamonRegion
-    hugepage_size = None    # hugepage size in bytes
+    hugepage_size = None    # list of min/max hugepage size in bytes
     damon_target_idx = None
     scheme = None
 
@@ -737,7 +737,11 @@ class DamosFilter:
         self.memcg_path = memcg_path
         self.allow = _damo_fmt_str.text_to_bool(allow)
         self.address_range = address_range
-        self.hugepage_size = hugepage_size
+        if hugepage_size is not None:
+            if not type(hugepage_size) is list and len(hugepage_size) != 2:
+                raise Exception('wrong hugepage_size for DamosFilter()')
+            self.hugepage_size = [
+                    _damo_fmt_str.text_to_bytes(x) for x in hugepage_size]
         if damon_target_idx != None:
             self.damon_target_idx = _damo_fmt_str.text_to_nr(damon_target_idx)
 
@@ -760,7 +764,12 @@ class DamosFilter:
             return ' '.join(words + [_damo_fmt_str.format_nr(
                     self.damon_target_idx, raw)])
         if self.filter_type == 'hugepage_size':
-            return ' '.join(words + [self.hugepage_size.to_str(raw)])
+            if self.hugepage_size is not None:
+                words.append(
+                        '[%s, %s]' %
+                        (_damo_fmt_str.format_sz(self.hugepage_size[0], raw),
+                         _damo_fmt_str.format_sz(self.hugepage_size[1], raw)))
+            return ' '.join(words)
 
     def __str__(self):
         return self.to_str(False)
@@ -776,6 +785,10 @@ class DamosFilter:
         # filter_pass has renamed to allow
         elif 'filter_pass' in kv:
             allow = kv['filter_pass']
+        if 'hugepage_size' in kv:
+            hugepage_size = kv['hugepage_size']
+        else:
+            hugepage_size = None
         return DamosFilter(
                 kv['filter_type'], kv['matching'],
                 allow,
@@ -783,7 +796,8 @@ class DamosFilter:
                 DamonRegion.from_kvpairs(kv['address_range'])
                     if kv['filter_type'] == 'addr' else None,
                 kv['damon_target_idx']
-                    if kv['filter_type'] == 'target' else None)
+                    if kv['filter_type'] == 'target' else None,
+                    hugepage_size=hugepage_size)
 
     def to_kvpairs(self, raw=False):
         return collections.OrderedDict([
@@ -795,7 +809,11 @@ class DamosFilter:
                 self.address_range != None else None),
             ('damon_target_idx',
                 _damo_fmt_str.format_nr(self.damon_target_idx, raw)
-                if self.damon_target_idx != None else None)])
+                if self.damon_target_idx != None else None),
+            ('hugepage_size',
+             [_damo_fmt_str.format_sz(x, raw) for x in self.hugepage_size]
+             if self.hugepage_size is not None else None),
+            ])
 
     def handled_by_ops(self):
         # whether this filter is handled by DAMON operations set layer
