@@ -16,6 +16,7 @@ import damo_diagnose
 import damo_features
 import damo_help
 import damo_lru_sort
+import damo_module
 import damo_monitor
 import damo_pa_layout
 import damo_reclaim
@@ -51,6 +52,8 @@ subcmds = [
             msg='replay the recorded data accesses'),
 
         # DAMON modules control
+        _damo_subcmds.DamoSubCmd(name='module', module=damo_module,
+                                 msg='control DAMON kernel modules'),
         _damo_subcmds.DamoSubCmd(name='reclaim', module=damo_reclaim,
             msg='control DAMON_RECLAIM'),
         _damo_subcmds.DamoSubCmd(name='lru_sort', module=damo_lru_sort,
