@@ -71,11 +71,54 @@ def handle_args(args):
         print(err)
         exit(-3)
 
+def tracepoint_from_args(args):
+    if not 'access' in args.do_record or args.snapshot is not None:
+        return None
+    if args.schemes_target_regions is False:
+        return _damo_records.perf_event_damon_aggregated
+    return _damo_records.perf_event_damos_before_apply
+
+def snapshot_requests_from_args(args):
+    ''' Returns snapshot_request and error '''
+    if not 'access' in args.do_record or args.snapshot is None:
+        return None, None
+
+    tried_regions_of = None
+    if args.schemes_target_regions:
+        tried_regions_of = []
+        for kidx, kd in enumerate(kdamonds):
+            for cidx, ctx in enumerate(kd.contexts):
+                for sidx, scheme in enumerate(ctx.schemes):
+                    tried_regions_of.append([kidx, cidx, sidx])
+
+    dfilters, err = _damon_args.damos_options_to_filters(
+            args.snapshot_damos_filter)
+    if err is not None:
+        return None, 'wrong --snapshot_damos_filters (%s)' % err
+
+    record_filter, err = _damo_records.args_to_filter(args)
+    if err is not None:
+        return None, err
+
+    return _damo_records.RecordGetRequest(
+            tried_regions_of=tried_regions_of, record_file=None,
+            snapshot_damos_filters=dfilters,
+            record_filter=record_filter, total_sz_only=False,
+            dont_merge_regions=False), None
+
 def mk_handle(args, kdamonds, monitoring_intervals):
-    if args.schemes_target_regions == False:
-        tracepoint = _damo_records.perf_event_damon_aggregated
+    tracepoint = tracepoint_from_args(args)
+    snapshot_request, err = snapshot_requests_from_args(args)
+    if err is not None:
+        print(err)
+        cleanup_exit(1)
+    if snapshot_request is not None:
+        snapshot_interval_sec = _damo_fmt_str.text_to_sec(
+                args.snapshot[0])
+        snapshot_count = _damo_fmt_str.text_to_nr(args.snapshot[1])
     else:
-        tracepoint = _damo_records.perf_event_damos_before_apply
+        snapshot_interval_sec = None
+        snapshot_count = None
 
     handle = _damo_records.RecordingHandle(
             # for access pattern monitoring
@@ -88,44 +131,11 @@ def mk_handle(args, kdamonds, monitoring_intervals):
             # for children processes recording and memory footprint
             kdamonds=kdamonds, add_child_tasks=args.include_child_tasks,
             record_mem_footprint='mem_footprint' in args.do_record,
-            record_vmas='vmas' in args.do_record, record_proc_stats=True,
-            timeout=args.timeout)
-
-    if args.snapshot is not None:
-        handle.tracepoint = None
-        tried_regions_of = None
-        if args.schemes_target_regions:
-            tried_regions_of = []
-            for kidx, kd in enumerate(kdamonds):
-                for cidx, ctx in enumerate(kd.contexts):
-                    for sidx, scheme in enumerate(ctx.schemes):
-                        tried_regions_of.append([kidx, cidx, sidx])
-
-        dfilters, err = _damon_args.damos_options_to_filters(
-                args.snapshot_damos_filter)
-        if err is not None:
-            print('wrong --snapshot_damos_filters (%s)' % err)
-            cleanup_exit(1)
-
-        record_filter, err = _damo_records.args_to_filter(args)
-        if err is not None:
-            print('record filter creation fail (%s)' % err)
-            cleanup_exit(1)
-
-        handle.snapshot_request = _damo_records.RecordGetRequest(
-                tried_regions_of=tried_regions_of, record_file=None,
-                snapshot_damos_filters=dfilters,
-                record_filter=record_filter, total_sz_only=False,
-                dont_merge_regions=False)
-        handle.snapshot_interval_sec = _damo_fmt_str.text_to_sec(
-                args.snapshot[0])
-        handle.snapshot_count = _damo_fmt_str.text_to_nr(args.snapshot[1])
-
-    if not 'access' in args.do_record:
-        handle.tracepoint = None
-        handle.snapshot_request = None
-    if not 'proc_stats' in args.do_record:
-        handle.proc_stats = None
+            record_vmas='vmas' in args.do_record,
+            record_proc_stats='proc_stats' in args.do_record,
+            timeout=args.timeout, snapshot_request=snapshot_request,
+            snapshot_interval_sec=snapshot_interval_sec,
+            snapshot_count=snapshot_count)
 
     return handle
 
