@@ -22,6 +22,9 @@ class GuideRegion:
         self.end_addr = end_addr
 
 class GuideInfo:
+    kdamond_idx = None
+    context_idx = None
+    scheme_idx = None
     tid = None
     start_time = None
     end_time = None
@@ -30,7 +33,10 @@ class GuideInfo:
     gaps = None
     contig_regions = None  # list of GuideRegion objects
 
-    def __init__(self, tid, start_time):
+    def __init__(self, kdamond_idx, context_idx, scheme_idx, tid, start_time):
+        self.kdamond_idx = kdamond_idx
+        self.context_idx = context_idx
+        self.scheme_idx = scheme_idx
         self.tid = tid
         self.start_time = start_time
         self.gaps = []
@@ -56,7 +62,11 @@ class GuideInfo:
         return ret
 
     def __str__(self):
-        lines = ['target_id:%d' % self.tid]
+        lines = [
+                'kdamond_idx: %s' % self.kdamond_idx,
+                'context_idx: %s' % self.context_idx,
+                'scheme_idx: %s' % self.scheme_idx,
+                'target_id: %s' % self.tid]
         lines.append('time: %d-%d (%s)' % (self.start_time, self.end_time,
                     _damo_fmt_str.format_time_ns(self.end_time - self.start_time,
                         False)))
@@ -87,16 +97,33 @@ def overlapping_regions(regions1, regions2):
             overlap_regions.append(r1)
     return overlap_regions
 
+def oldest_monitor_time(snapshot, record_intervals):
+    if record_intervals is None:
+        return snapshot.start_time
+    longest_age = 0
+    for region in snapshot.regions:
+        if longest_age < region.age.aggr_intervals:
+            longest_age = region.age.aggr_intervals
+    aggr_interval_ns = record_intervals.aggr * 1000
+    return snapshot.start_time - longest_age * aggr_interval_ns
+
+def rec_to_guide_id(record):
+    return '%s %s %s %s' % (record.kdamond_idx, record.context_idx,
+                            record.scheme_idx, record.target_id)
+
 def get_guide_info(records):
     "return the set of guide information for the moitoring result"
     guides = {}
     for record in records:
+        guide_id = rec_to_guide_id(record)
         for snapshot in record.snapshots:
+            if not guide_id in guides:
+                guides[guide_id] = GuideInfo(
+                        record.kdamond_idx, record.context_idx,
+                        record.scheme_idx, record.target_id,
+                        oldest_monitor_time(snapshot, record.intervals))
+            guide = guides[guide_id]
             monitor_time = snapshot.end_time
-            tid = record.target_id
-            if not tid in guides:
-                guides[tid] = GuideInfo(tid, monitor_time)
-            guide = guides[tid]
             guide.end_time = monitor_time
 
             last_addr = None
@@ -122,14 +149,14 @@ def get_guide_info(records):
             else:
                 guide.gaps = overlapping_regions(guide.gaps, gaps)
 
-    for tid, guide in guides.items():
+    for guide_id, guide in guides.items():
         guide_regions = []
         for start, end in guide.regions():
             guide_regions.append(GuideRegion(start, end))
         guide.contig_regions = guide_regions
 
         for record in records:
-            if record.target_id != tid:
+            if rec_to_guide_id(record) != guide_id:
                 continue
             for snapshot in record.snapshots:
                 for region in snapshot.regions:
