@@ -662,7 +662,8 @@ def heatmap_pixels_minmax_temps(snapshot, sz_unit, fmt):
             start = end
     return pixels, min_temperature, max_temperature
 
-def heatmap_dots(pixels, min_temperature, max_temperature, fmt):
+def heatmap_dots(
+        pixels, min_temperature, max_temperature, fmt, sz_unit, static):
     max_color_level = _damo_ascii_color.max_color_level()
     temperature_unit = (max_temperature - min_temperature) / max_color_level
     # single region?
@@ -702,7 +703,8 @@ def heatmap_str(snapshot, record, fmt):
 
     pixels, min_temperature, max_temperature = heatmap_pixels_minmax_temps(
             snapshot, sz_unit, fmt)
-    dots = heatmap_dots(pixels, min_temperature, max_temperature, fmt)
+    dots = heatmap_dots(
+            pixels, min_temperature, max_temperature, fmt, sz_unit, static)
 
     comment = '# min/max temperatures: %s, %s, column size: %s' % (
             _damo_fmt_str.format_nr(min_temperature, raw),
@@ -1661,13 +1663,12 @@ def read_and_show(args):
             translate_records_to_cache_space(
                     records, sz_cache, ways_cache, sz_cache_line)
 
-        for record in records:
-            try:
-                pr_records(fmt, records,
-                           dont_use_pager = args.repeat is not None)
-            except BrokenPipeError as e:
-                # maybe user piped to 'less' like pager, and quit from it
-                pass
+        try:
+            pr_records(fmt, records,
+                       dont_use_pager = args.repeat is not None)
+        except BrokenPipeError as e:
+            # maybe user piped to 'less' like pager, and quit from it
+            pass
 
         time.sleep(repeat_delay)
         read_show_count += 1
