@@ -4,7 +4,7 @@
 bindir=$(dirname "$0")
 cd "$bindir" || exit 1
 
-for test_dir in unit record report schemes \
+for test_dir in unit pre-commit record report schemes \
 	damon_reclaim damon_lru_sort start_stop
 do
 	if ! "./$test_dir/test.sh"
