@@ -7,10 +7,11 @@ import _test_damo_common
 
 _test_damo_common.add_damo_dir_to_syspath()
 
+import _damo_fs
 import _damon_sysfs
 
 class TestDamonSysfs(unittest.TestCase):
-    def test_json_kdamonds_convert(self):
+    def test_json_kdamonds_staging(self):
         _damon_sysfs.feature_supports = {
                 'fvaddr': True,
                 'init_regions': True,
@@ -86,62 +87,51 @@ class TestDamonSysfs(unittest.TestCase):
                         },
                     }
                 }
+        expected_dryrun_log = [
+                "read 'nr_kdamonds': '0'",
+                "write '1' to 'nr_kdamonds'",
+                "read '0/contexts/nr_contexts': '0'",
+                "write '1' to '0/contexts/nr_contexts'",
+                "write 'paddr' to '0/contexts/0/operations'",
+                "write '5000' to '0/contexts/0/monitoring_attrs/intervals/sample_us'",
+                "write '200000' to '0/contexts/0/monitoring_attrs/intervals/aggr_us'",
+                "write '1000000' to '0/contexts/0/monitoring_attrs/intervals/update_us'",
+                "write '10' to '0/contexts/0/monitoring_attrs/nr_regions/min'",
+                "write '1000' to '0/contexts/0/monitoring_attrs/nr_regions/max'",
+                "read '0/contexts/0/targets/nr_targets': '0'",
+                "read '0/contexts/0/schemes/nr_schemes': '0'",
+                "write '1' to '0/contexts/0/schemes/nr_schemes'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/sz/min'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/sz/max'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/nr_accesses/min'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/nr_accesses/max'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/age/min'",
+                "write '0' to '0/contexts/0/schemes/0/access_pattern/age/max'",
+                "write 'stat' to '0/contexts/0/schemes/0/action'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/ms'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/bytes'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/reset_interval_ms'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/weights/sz_permil'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/weights/nr_accesses_permil'",
+                "write '0' to '0/contexts/0/schemes/0/quotas/weights/age_permil'",
+                "write 'none' to '0/contexts/0/schemes/0/watermarks/metric'",
+                "write '0' to '0/contexts/0/schemes/0/watermarks/interval_us'",
+                "write '0' to '0/contexts/0/schemes/0/watermarks/high'",
+                "write '0' to '0/contexts/0/schemes/0/watermarks/mid'",
+                "write '0' to '0/contexts/0/schemes/0/watermarks/low'",
+                ]
 
-        expected_wops = {
-                "0": {
-                    "contexts": {
-                        "0": [
-                            {"operations": "paddr"},
-                            {
-                                "monitoring_attrs": {
-                                    "intervals": {
-                                        "sample_us": "5000",
-                                        "aggr_us": "200000",
-                                        "update_us": "1000000"
-                                        },
-                                    "nr_regions": {"max": "1000", "min": "10"}
-                                    }
-                                },
-                            {"targets": {}},
-                            {
-                                "schemes": {
-                                    "0": {
-                                        "access_pattern": {
-                                            "age": {"max": "0", "min": "0"},
-                                            "nr_accesses": {
-                                                "max": "0", "min": "0"},
-                                            "sz": {"max": "0", "min": "0"}
-                                            },
-                                        "action": "stat",
-                                        "apply_interval_us": "0",
-                                        "quotas": {
-                                            "bytes": "0", "ms": "0",
-                                            "reset_interval_ms": "0",
-                                            "goals": {},
-                                            "weights": {
-                                                "age_permil": "0",
-                                                "nr_accesses_permil": "0",
-                                                "sz_permil": "0"
-                                                }
-                                            },
-                                        "watermarks": {
-                                            "metric": "none",
-                                            "interval_us": "0", "high": "0",
-                                            "mid": "0", "low": "0",
-                                            },
-                                        "filters": {
-                                            }
-                                        }
-                                    }
-                                }
-                            ]
-                        }
-                    }
-                }
-
+        _damo_fs.debug_dryrun(
+                {
+                    'nr_kdamonds': '0',
+                    '0/contexts/nr_contexts': '0',
+                    '0/contexts/0/targets/nr_targets': '0',
+                    '0/contexts/0/schemes/nr_schemes': '0',
+                    })
         kdamonds = _damon_sysfs.files_content_to_kdamonds(sysfs_dict)
-        wops = _damon_sysfs.wops_for_kdamonds(kdamonds)
-        self.assertEqual(expected_wops, wops)
+        _damon_sysfs.write_kdamonds_dir('', kdamonds)
+        logs = _damo_fs.debug_get_dryrun_logs()
+        self.assertEqual(expected_dryrun_log, logs)
 
 if __name__ == '__main__':
     unittest.main()
